@@ -6,7 +6,10 @@ use HTML::HTPL::Sys qw(publish);
 require Exporter;
 
 @ISA = qw(Exporter);
-@EXPORT = qw(seperate);
+@EXPORT = qw();
+
+####
+## Create a resultset
 
 sub new {
     my $class = shift;
@@ -271,7 +274,7 @@ sub project ($$;@) {
     &HTML::HTPL::Sys::pushvars($self->{'fields'});
     $self->rewind;
     my $ref = UNIVERSAL::isa($fields[0], 'CODE') ? $fields[0] : (
-         !$#fields ? sub {my $self = shift; $self->get($field);} :
+         !$#fields ? sub {my $self = shift; $self->get($fields[0]);} :
          sub {my $self = shift; [map {$self->get($_);} @fields];});
     while ($self->fetch) {
         push(@r, &$ref($self));
